==> libwacom-0.18.tar.bz2: libwacom-0.18/doc/html/search/functions_0.js <==
var searchData=
[
  ['libwacom_5fcompare',['libwacom_compare',['../libwacom_8h.html#a9dcb4a85cb411593a9ea043c0130c1e9',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fdestroy',['libwacom_database_destroy',['../libwacom_8h.html#afdc100499a3d0760a53ec19d28ce1b12',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fnew',['libwacom_database_new',['../libwacom_8h.html#ad9220728a9e077d86e652625eef17dca',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fnew_5ffor_5fpath',['libwacom_database_new_for_path',['../libwacom_8h.html#a7283183d04c1dd28ef95936b84af5e88',1,'libwacom.h']]],
  ['libwacom_5fdestroy',['libwacom_destroy',['../libwacom_8h.html#a6ef7b31ab0e7039ee3aeb85fd02cb892',1,'libwacom.h']]],
  ['libwacom_5ferror_5ffree',['libwacom_error_free',['../libwacom_8h.html#a6864ec1cbb3582b386ff13fa5e23d366',1,'libwacom.h']]],
  ['libwacom_5ferror_5fget_5fcode',['libwacom_error_get_code',['../libwacom_8h.html#a7835e4ff16a2f3360ffe61769d8f009e',1,'libwacom.h']]],
  ['libwacom_5ferror_5fget_5fmessage',['libwacom_error_get_message',['../libwacom_8h.html#a6f44878163668d0c67d5fa0d5cda8658',1,'libwacom.h']]],
  ['libwacom_5ferror_5fnew',['libwacom_error_new',['../libwacom_8h.html#a2b2eedf5db08f000ca4bf245d9b62dfb',1,'libwacom.h']]],
  ['libwacom_5fget_5fbustype',['libwacom_get_bustype',['../libwacom_8h.html#ab3aa4c14e02a61c84fa67e9752bdfece',1,'libwacom.h']]],
  ['libwacom_5fget_5fbutton_5fflag',['libwacom_get_button_flag',['../libwacom_8h.html#ab62583042419e89507662048fc7593ac',1,'libwacom.h']]],
  ['libwacom_5fget_5fbutton_5fled_5fgroup',['libwacom_get_button_led_group',['../libwacom_8h.html#a505f528225b6ffe639d3b44faecd4449',1,'libwacom.h']]],
  ['libwacom_5fget_5fclass',['libwacom_get_class',['../libwacom_8h.html#abfaefac844ab6fdeb31c7ce5b322fd6d',1,'libwacom.h']]],
  ['libwacom_5fget_5fheight',['libwacom_get_height',['../libwacom_8h.html#ac925a601e2f6b894d11b285aaf811d21',1,'libwacom.h']]],
  ['libwacom_5fget_5fintegration_5fflags',['libwacom_get_integration_flags',['../libwacom_8h.html#a88efa2a2a569569563e81f578c7730fc',1,'libwacom.h']]],
  ['libwacom_5fget_5flayout_5ffilename',['libwacom_get_layout_filename',['../libwacom_8h.html#a3bfbfbd2b85bda1f131ea68cf2e0d187',1,'libwacom.h']]],
  ['libwacom_5fget_5fmatch',['libwacom_get_match',['../libwacom_8h.html#ae64c378cf394c6a0b929a9d9b0a4533f',1,'libwacom.h']]],
  ['libwacom_5fget_5fmatches',['libwacom_get_matches',['../libwacom_8h.html#a47740fce8aad7367cf5118d75764a68f',1,'libwacom.h']]],
  ['libwacom_5fget_5fname',['libwacom_get_name',['../libwacom_8h.html#a7e37d3343b9b63a4a86db8a1e5806221',1,'libwacom.h']]],
  ['libwacom_5fget_5fnum_5fbuttons',['libwacom_get_num_buttons',['../libwacom_8h.html#ac6e0aa5a3662ec1b2d098c6a7ecd5428',1,'libwacom.h']]],
  ['libwacom_5fget_5fnum_5fstrips',['libwacom_get_num_strips',['../libwacom_8h.html#a105c271d2b22303d856514292109dc29',1,'libwacom.h']]],
  ['libwacom_5fget_5fproduct_5fid',['libwacom_get_product_id',['../libwacom_8h.html#a4cc98b52f83e83569e6e6a65afd36f42',1,'libwacom.h']]],
  ['libwacom_5fget_5fring2_5fnum_5fmodes',['libwacom_get_ring2_num_modes',['../libwacom_8h.html#acfe819bab775ec3b8517bdb65b0a7019',1,'libwacom.h']]],
  ['libwacom_5fget_5fring_5fnum_5fmodes',['libwacom_get_ring_num_modes',['../libwacom_8h.html#a1fc38e403f4b04f7b486bb469f1ae691',1,'libwacom.h']]],
  ['libwacom_5fget_5fstatus_5fleds',['libwacom_get_status_leds',['../libwacom_8h.html#a4b023b830ddfcbbff8279ac9956afe38',1,'libwacom.h']]],
  ['libwacom_5fget_5fstrips_5fnum_5fmodes',['libwacom_get_strips_num_modes',['../libwacom_8h.html#a19234b61d298ee588d66021c98e24ca7',1,'libwacom.h']]],
  ['libwacom_5fget_5fsupported_5fstyli',['libwacom_get_supported_styli',['../libwacom_8h.html#addf68593ec4434e218211e9fd15a22fb',1,'libwacom.h']]],
  ['libwacom_5fget_5fvendor_5fid',['libwacom_get_vendor_id',['../libwacom_8h.html#a6c1052b0c91503cbc4427805ccc92111',1,'libwacom.h']]],
  ['libwacom_5fget_5fwidth',['libwacom_get_width',['../libwacom_8h.html#a1d3a693813f8798f41e8754603b8b430',1,'libwacom.h']]],
  ['libwacom_5fhas_5fring',['libwacom_has_ring',['../libwacom_8h.html#af69a5a5b89d1b18c11f7153dfb43c227',1,'libwacom.h']]],
  ['libwacom_5fhas_5fring2',['libwacom_has_ring2',['../libwacom_8h.html#a8d51e232cf392f7c46ed735b47379f8d',1,'libwacom.h']]],
  ['libwacom_5fhas_5fstylus',['libwacom_has_stylus',['../libwacom_8h.html#a07869844856ccbdd2c18599a79775e34',1,'libwacom.h']]],
  ['libwacom_5fhas_5ftouch',['libwacom_has_touch',['../libwacom_8h.html#a2eb8125b1fe03130c32883a3513a73cf',1,'libwacom.h']]],
  ['libwacom_5fhas_5ftouchswitch',['libwacom_has_touchswitch',['../libwacom_8h.html#ad0b5f2c32765d1d4d6cb637dd7c1acaa',1,'libwacom.h']]],
  ['libwacom_5fis_5fbuiltin',['libwacom_is_builtin',['../libwacom_8h.html#a802170200f00ba89d4b5d2f4f0bc88a4',1,'libwacom.h']]],
  ['libwacom_5fis_5freversible',['libwacom_is_reversible',['../libwacom_8h.html#aa52facf4eda6bdd89f4fb15dabe8bfd8',1,'libwacom.h']]],
  ['libwacom_5flist_5fdevices_5ffrom_5fdatabase',['libwacom_list_devices_from_database',['../libwacom_8h.html#a0e77418c20ce3bfdf217ec12524f232c',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fbustype',['libwacom_match_get_bustype',['../libwacom_8h.html#a9159afd9136fb5f712669d0472553fc5',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fmatch_5fstring',['libwacom_match_get_match_string',['../libwacom_8h.html#af46230253f8009987a620705cccf7634',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fname',['libwacom_match_get_name',['../libwacom_8h.html#a37bbe762737a4dc1901325d3206fc443',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fproduct_5fid',['libwacom_match_get_product_id',['../libwacom_8h.html#aa447133161dd5529d4c45a6b2addd150',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fvendor_5fid',['libwacom_match_get_vendor_id',['../libwacom_8h.html#aa11e234a0e3bb7f4d939d1abc66c9c19',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fname',['libwacom_new_from_name',['../libwacom_8h.html#ae58659a01922c67e9fd9129f68a60b0b',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fpath',['libwacom_new_from_path',['../libwacom_8h.html#a903b1bee3d0746431c475cf91fec2b88',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fusbid',['libwacom_new_from_usbid',['../libwacom_8h.html#addabb8c08addad39d75cf9ab4da2f725',1,'libwacom.h']]],
  ['libwacom_5fprint_5fdevice_5fdescription',['libwacom_print_device_description',['../libwacom_8h.html#a65ba967a40c4171d8188dff64cff2efd',1,'libwacom.h']]],
  ['libwacom_5fprint_5fstylus_5fdescription',['libwacom_print_stylus_description',['../libwacom_8h.html#a84b9c038c3d9f53c8c9fed4ff30f71f2',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5faxes',['libwacom_stylus_get_axes',['../libwacom_8h.html#a28c212a70b84efb5d06460c95f87d6d2',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5ffor_5fid',['libwacom_stylus_get_for_id',['../libwacom_8h.html#a2a54e14b86da667ede181e28f6091952',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fid',['libwacom_stylus_get_id',['../libwacom_8h.html#a3bf965e3a2f36456e199937f47987ff3',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fname',['libwacom_stylus_get_name',['../libwacom_8h.html#a60160e5e8d1c2c8a24a24e803d83a597',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fnum_5fbuttons',['libwacom_stylus_get_num_buttons',['../libwacom_8h.html#ad9d62c054e587e4453074c25969bb97b',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5ftype',['libwacom_stylus_get_type',['../libwacom_8h.html#a17d53291902335a21b0d30dbaee15bf9',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5feraser',['libwacom_stylus_has_eraser',['../libwacom_8h.html#aa5042d687a5ca7c3b8625d7db1143356',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5flens',['libwacom_stylus_has_lens',['../libwacom_8h.html#a3302fa288fae4c8057ae75d4120c075e',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5fwheel',['libwacom_stylus_has_wheel',['../libwacom_8h.html#a25750936d41579fa5cb0d5296e68d7f8',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fis_5feraser',['libwacom_stylus_is_eraser',['../libwacom_8h.html#adeebad73b4bce9f9791ef59e07b8c051',1,'libwacom.h']]]
];

==> libwacom-0.24.tar.bz2: libwacom-0.24/doc/html/search/functions_0.js <==
var searchData=
[
  ['libwacom_5fcompare',['libwacom_compare',['../libwacom_8h.html#a9dcb4a85cb411593a9ea043c0130c1e9',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fdestroy',['libwacom_database_destroy',['../libwacom_8h.html#afdc100499a3d0760a53ec19d28ce1b12',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fnew',['libwacom_database_new',['../libwacom_8h.html#ad9220728a9e077d86e652625eef17dca',1,'libwacom.h']]],
  ['libwacom_5fdatabase_5fnew_5ffor_5fpath',['libwacom_database_new_for_path',['../libwacom_8h.html#a7283183d04c1dd28ef95936b84af5e88',1,'libwacom.h']]],
  ['libwacom_5fdestroy',['libwacom_destroy',['../libwacom_8h.html#a6ef7b31ab0e7039ee3aeb85fd02cb892',1,'libwacom.h']]],
  ['libwacom_5ferror_5ffree',['libwacom_error_free',['../libwacom_8h.html#a6864ec1cbb3582b386ff13fa5e23d366',1,'libwacom.h']]],
  ['libwacom_5ferror_5fget_5fcode',['libwacom_error_get_code',['../libwacom_8h.html#a7835e4ff16a2f3360ffe61769d8f009e',1,'libwacom.h']]],
  ['libwacom_5ferror_5fget_5fmessage',['libwacom_error_get_message',['../libwacom_8h.html#a6f44878163668d0c67d5fa0d5cda8658',1,'libwacom.h']]],
  ['libwacom_5ferror_5fnew',['libwacom_error_new',['../libwacom_8h.html#a2b2eedf5db08f000ca4bf245d9b62dfb',1,'libwacom.h']]],
  ['libwacom_5fget_5fbustype',['libwacom_get_bustype',['../libwacom_8h.html#ab3aa4c14e02a61c84fa67e9752bdfece',1,'libwacom.h']]],
  ['libwacom_5fget_5fbutton_5fflag',['libwacom_get_button_flag',['../libwacom_8h.html#ab62583042419e89507662048fc7593ac',1,'libwacom.h']]],
  ['libwacom_5fget_5fbutton_5fled_5fgroup',['libwacom_get_button_led_group',['../libwacom_8h.html#a505f528225b6ffe639d3b44faecd4449',1,'libwacom.h']]],
  ['libwacom_5fget_5fclass',['libwacom_get_class',['../libwacom_8h.html#abfaefac844ab6fdeb31c7ce5b322fd6d',1,'libwacom.h']]],
  ['libwacom_5fget_5fheight',['libwacom_get_height',['../libwacom_8h.html#ac925a601e2f6b894d11b285aaf811d21',1,'libwacom.h']]],
  ['libwacom_5fget_5fintegration_5fflags',['libwacom_get_integration_flags',['../libwacom_8h.html#a88efa2a2a569569563e81f578c7730fc',1,'libwacom.h']]],
  ['libwacom_5fget_5flayout_5ffilename',['libwacom_get_layout_filename',['../libwacom_8h.html#a3bfbfbd2b85bda1f131ea68cf2e0d187',1,'libwacom.h']]],
  ['libwacom_5fget_5fmatch',['libwacom_get_match',['../libwacom_8h.html#ae64c378cf394c6a0b929a9d9b0a4533f',1,'libwacom.h']]],
  ['libwacom_5fget_5fmatches',['libwacom_get_matches',['../libwacom_8h.html#a47740fce8aad7367cf5118d75764a68f',1,'libwacom.h']]],
  ['libwacom_5fget_5fname',['libwacom_get_name',['../libwacom_8h.html#a7e37d3343b9b63a4a86db8a1e5806221',1,'libwacom.h']]],
  ['libwacom_5fget_5fnum_5fbuttons',['libwacom_get_num_buttons',['../libwacom_8h.html#ac6e0aa5a3662ec1b2d098c6a7ecd5428',1,'libwacom.h']]],
  ['libwacom_5fget_5fnum_5fstrips',['libwacom_get_num_strips',['../libwacom_8h.html#a105c271d2b22303d856514292109dc29',1,'libwacom.h']]],
  ['libwacom_5fget_5fpaired_5fdevice',['libwacom_get_paired_device',['../libwacom_8h.html#a6d488e20510dac2d1bc56f69f8ec8097',1,'libwacom.h']]],
  ['libwacom_5fget_5fproduct_5fid',['libwacom_get_product_id',['../libwacom_8h.html#a4cc98b52f83e83569e6e6a65afd36f42',1,'libwacom.h']]],
  ['libwacom_5fget_5fring2_5fnum_5fmodes',['libwacom_get_ring2_num_modes',['../libwacom_8h.html#acfe819bab775ec3b8517bdb65b0a7019',1,'libwacom.h']]],
  ['libwacom_5fget_5fring_5fnum_5fmodes',['libwacom_get_ring_num_modes',['../libwacom_8h.html#a1fc38e403f4b04f7b486bb469f1ae691',1,'libwacom.h']]],
  ['libwacom_5fget_5fstatus_5fleds',['libwacom_get_status_leds',['../libwacom_8h.html#a4b023b830ddfcbbff8279ac9956afe38',1,'libwacom.h']]],
  ['libwacom_5fget_5fstrips_5fnum_5fmodes',['libwacom_get_strips_num_modes',['../libwacom_8h.html#a19234b61d298ee588d66021c98e24ca7',1,'libwacom.h']]],
  ['libwacom_5fget_5fsupported_5fstyli',['libwacom_get_supported_styli',['../libwacom_8h.html#addf68593ec4434e218211e9fd15a22fb',1,'libwacom.h']]],
  ['libwacom_5fget_5fvendor_5fid',['libwacom_get_vendor_id',['../libwacom_8h.html#a6c1052b0c91503cbc4427805ccc92111',1,'libwacom.h']]],
  ['libwacom_5fget_5fwidth',['libwacom_get_width',['../libwacom_8h.html#a1d3a693813f8798f41e8754603b8b430',1,'libwacom.h']]],
  ['libwacom_5fhas_5fring',['libwacom_has_ring',['../libwacom_8h.html#af69a5a5b89d1b18c11f7153dfb43c227',1,'libwacom.h']]],
  ['libwacom_5fhas_5fring2',['libwacom_has_ring2',['../libwacom_8h.html#a8d51e232cf392f7c46ed735b47379f8d',1,'libwacom.h']]],
  ['libwacom_5fhas_5fstylus',['libwacom_has_stylus',['../libwacom_8h.html#a07869844856ccbdd2c18599a79775e34',1,'libwacom.h']]],
  ['libwacom_5fhas_5ftouch',['libwacom_has_touch',['../libwacom_8h.html#a2eb8125b1fe03130c32883a3513a73cf',1,'libwacom.h']]],
  ['libwacom_5fhas_5ftouchswitch',['libwacom_has_touchswitch',['../libwacom_8h.html#ad0b5f2c32765d1d4d6cb637dd7c1acaa',1,'libwacom.h']]],
  ['libwacom_5fis_5fbuiltin',['libwacom_is_builtin',['../libwacom_8h.html#a802170200f00ba89d4b5d2f4f0bc88a4',1,'libwacom.h']]],
  ['libwacom_5fis_5freversible',['libwacom_is_reversible',['../libwacom_8h.html#aa52facf4eda6bdd89f4fb15dabe8bfd8',1,'libwacom.h']]],
  ['libwacom_5flist_5fdevices_5ffrom_5fdatabase',['libwacom_list_devices_from_database',['../libwacom_8h.html#a0e77418c20ce3bfdf217ec12524f232c',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fbustype',['libwacom_match_get_bustype',['../libwacom_8h.html#a9159afd9136fb5f712669d0472553fc5',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fmatch_5fstring',['libwacom_match_get_match_string',['../libwacom_8h.html#af46230253f8009987a620705cccf7634',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fname',['libwacom_match_get_name',['../libwacom_8h.html#a37bbe762737a4dc1901325d3206fc443',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fproduct_5fid',['libwacom_match_get_product_id',['../libwacom_8h.html#aa447133161dd5529d4c45a6b2addd150',1,'libwacom.h']]],
  ['libwacom_5fmatch_5fget_5fvendor_5fid',['libwacom_match_get_vendor_id',['../libwacom_8h.html#aa11e234a0e3bb7f4d939d1abc66c9c19',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fname',['libwacom_new_from_name',['../libwacom_8h.html#ae58659a01922c67e9fd9129f68a60b0b',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fpath',['libwacom_new_from_path',['../libwacom_8h.html#a903b1bee3d0746431c475cf91fec2b88',1,'libwacom.h']]],
  ['libwacom_5fnew_5ffrom_5fusbid',['libwacom_new_from_usbid',['../libwacom_8h.html#addabb8c08addad39d75cf9ab4da2f725',1,'libwacom.h']]],
  ['libwacom_5fprint_5fdevice_5fdescription',['libwacom_print_device_description',['../libwacom_8h.html#a65ba967a40c4171d8188dff64cff2efd',1,'libwacom.h']]],
  ['libwacom_5fprint_5fstylus_5fdescription',['libwacom_print_stylus_description',['../libwacom_8h.html#a84b9c038c3d9f53c8c9fed4ff30f71f2',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5faxes',['libwacom_stylus_get_axes',['../libwacom_8h.html#a28c212a70b84efb5d06460c95f87d6d2',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5ffor_5fid',['libwacom_stylus_get_for_id',['../libwacom_8h.html#a2a54e14b86da667ede181e28f6091952',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fid',['libwacom_stylus_get_id',['../libwacom_8h.html#a3bf965e3a2f36456e199937f47987ff3',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fname',['libwacom_stylus_get_name',['../libwacom_8h.html#a60160e5e8d1c2c8a24a24e803d83a597',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5fnum_5fbuttons',['libwacom_stylus_get_num_buttons',['../libwacom_8h.html#ad9d62c054e587e4453074c25969bb97b',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fget_5ftype',['libwacom_stylus_get_type',['../libwacom_8h.html#a17d53291902335a21b0d30dbaee15bf9',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5feraser',['libwacom_stylus_has_eraser',['../libwacom_8h.html#aa5042d687a5ca7c3b8625d7db1143356',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5flens',['libwacom_stylus_has_lens',['../libwacom_8h.html#a3302fa288fae4c8057ae75d4120c075e',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fhas_5fwheel',['libwacom_stylus_has_wheel',['../libwacom_8h.html#a25750936d41579fa5cb0d5296e68d7f8',1,'libwacom.h']]],
  ['libwacom_5fstylus_5fis_5feraser',['libwacom_stylus_is_eraser',['../libwacom_8h.html#adeebad73b4bce9f9791ef59e07b8c051',1,'libwacom.h']]]
];
